package com.isaiahvonrundstedt.fokus.features.task

import android.content.Context
import android.os.Parcelable
import androidx.room.*
import com.isaiahvonrundstedt.fokus.R
import com.isaiahvonrundstedt.fokus.components.extensions.jodatime.isToday
import com.isaiahvonrundstedt.fokus.components.extensions.jodatime.isTomorrow
import com.isaiahvonrundstedt.fokus.components.extensions.jodatime.isYesterday
import com.isaiahvonrundstedt.fokus.database.converter.DateTimeConverter
import com.isaiahvonrundstedt.fokus.features.subject.Subject
import com.squareup.moshi.JsonClass
import kotlinx.android.parcel.Parcelize
import org.joda.time.DateTime
import org.joda.time.format.DateTimeFormat
import java.util.*

@Parcelize
@JsonClass(generateAdapter = true)
@Entity(tableName = "tasks", foreignKeys = [
    ForeignKey(entity = Subject::class, parentColumns = arrayOf("subjectID"),
        childColumns = arrayOf("subject"), onDelete = ForeignKey.SET_NULL)])
data class Task @JvmOverloads constructor(
    @PrimaryKey
    @ColumnInfo(index = true)
    var taskID: String = UUID.randomUUID().toString(),
    var name: String? = null,
    var notes: String? = null,
    var subject: String? = null,
    var isImportant: Boolean = false,
    @TypeConverters(DateTimeConverter::class)
    var dateAdded: DateTime? = DateTime.now(),
    @TypeConverters(DateTimeConverter::class)
    var dueDate: DateTime? = null,
    var isFinished: Boolean = false
) : Parcelable {

    fun hasDueDate(): Boolean {
        return dueDate != null
    }

    fun isDueDateInFuture(): Boolean {
        return dueDate?.isAfterNow == true
    }

    fun isDueToday(): Boolean {
        return dueDate?.isToday() == true
    }

    fun formatDueDate(context: Context): String? {
        if (dueDate == null)
            return null

        // Check if the day on the task's due is today
        return if (dueDate!!.isToday())
            String.format(context.getString(R.string.today_at),
                DateTimeFormat.forPattern(DateTimeConverter.FORMAT_TIME).print(dueDate))
        // Now check if the day is yesterday
        else if (dueDate!!.isYesterday())
            String.format(context.getString(R.string.yesterday_at),
                DateTimeFormat.forPattern(DateTimeConverter.FORMAT_TIME).print(dueDate))
        // Now check if its tomorrow
        else if (dueDate!!.isTomorrow())
            String.format(context.getString(R.string.tomorrow_at),
                DateTimeFormat.forPattern(DateTimeConverter.FORMAT_TIME).print(dueDate))
        // Just print the date what could go wrong?
        else DateTimeFormat.forPattern(DateTimeConverter.FORMAT_DATE).print(dueDate)
    }
}